var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference =
[
    [ "com::sun::star::text::TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
    [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
    [ "ReferenceFieldFlags", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#a4be748ddcbe4a3be2ca7d992aaa2854b", null ],
    [ "ReferenceFieldLanguage", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#af3c825ff9d0135190ffbdda18debaa85", null ],
    [ "ReferenceFieldPart", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#a18729f76cab36732f97d3b3361e7c4d4", null ],
    [ "ReferenceFieldSource", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#ae3262783bf541442ecacd4c024694367", null ],
    [ "SequenceNumber", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#af4b5be2e3a776cf04f13bcfb5d0797fa", null ],
    [ "SourceName", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1GetReference.html#a651798f55a94e395df9f863283ef447c", null ]
];